module Main ( main ) where

import qualified Core.Configuration            as Configuration
import qualified Core.HTTP                     as HTTP
import qualified Core.SQLite                   as DB
import           Core.Types

import           Crypto.Saltine                (sodiumInit)
import           GHC.Natural                   (popCountNatural)
import           Prelude                       hiding (id)
import           Web.Scotty

-- Purr's entrypoint
main :: IO () 
main = do
  -- Initialize the RNG used for sodium encryption (Saltine library)
  sodiumInit 
  {- Initialize our dotenv configuration which reads from a .env configuration
     if any required variables are missing from the provided environment -}
  Configuration.init
  {- Initialize the encryption key file if it doesn't
     exist yet or use the existing key -}
  Configuration.keyFileInit 
  {- Initialize our database by ensuring the SQLite file exists
     and has tables setup as the application expects -}
  DB.init
  {- Get the configured port to run on and start the Scotty webserver app
     defined in HTTP.app -}
  port <- Configuration.appPort
  env <- Configuration.getRuntimeEnvironment
  scotty (read port) (HTTP.app env)
